@@ -256,7 +256,10 @@ class Message(models.Model):
         null=True,
     )
 
-    attachments = models.ManyToManyField(MessageAttachment)
+    attachments = models.ManyToManyField(
+        MessageAttachment,
+        blank=True,
+    )
 
     objects = models.Manager()
     unread_messages = UnreadMessageManager()
@@ -321,4 +324,4 @@ class Message(models.Model):
         return email.message_from_string(self.body)
 
     def __unicode__(self):
-        return self.subject
\ No newline at end of file
+        return self.subject
